pub struct McpSandboxContext { /* private fields */ }Expand description
Sandbox policy and launch context inherited by MCP stdio providers.
Implementations
Sourceimpl McpSandboxContext
impl McpSandboxContext
Sourcepub fn new(policy: SandboxPolicy, sandbox_cwd: impl Into<PathBuf>) -> Self
pub fn new(policy: SandboxPolicy, sandbox_cwd: impl Into<PathBuf>) -> Self
Create a context using the configured workspace as the sandbox cwd.
Sourcepub fn with_linux_sandbox_executable(
self,
executable: impl Into<PathBuf>,
) -> Self
pub fn with_linux_sandbox_executable( self, executable: impl Into<PathBuf>, ) -> Self
Override the Linux helper path, primarily for embedding applications and tests.
Sourcepub fn policy(&self) -> &SandboxPolicy
pub fn policy(&self) -> &SandboxPolicy
Return the policy carried by this context.