Module types

Module types 

Core MCP data types for tool, resource, and prompt information.

Structs

FileParamSchemaEntry
Masked schema entry for a file parameter in a tool’s input schema.
FileUploadResult
Result of uploading a local file to the backend.
McpClientStatus
Snapshot describing the MCP client at runtime.
McpElicitationRequest
Request payload for handling elicitation prompts from MCP providers.
McpElicitationResponse
Result returned by an elicitation handler after interacting with the user.
McpPromptDetail
Fully rendered MCP prompt ready for use.
McpPromptInfo
Summary of an MCP prompt exposed by a provider.
McpResourceData
Resource contents fetched from an MCP provider.
McpResourceInfo
Summary of an MCP resource exposed by a provider.
McpToolInfo
Information about an MCP tool exposed by a provider.
ProvidedFilePayload
Shape of a file payload provided by the client after upload.

Constants

OPENAI_FILE_PARAMS_META_KEY
Metadata key used in tool input schemas to indicate file upload parameters.
OPENAI_FILE_PARAMS_VALUE