pub struct ProvidedFilePayload { /* private fields */ }Expand description
Shape of a file payload provided by the client after upload.
This is the object shape that MCP tools expecting file uploads expect to receive. The client uploads local files to the backend and replaces the local file path with this structure.